<?php
declare(strict_types=1);
namespace App\Controller;

use App\JsonRpc\NewsServiceInterface;
use App\Tools\PublicData;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use Hyperf\Context\Context;
/**
 * Class NewsController
 * @package App\Controller
 */
//#[AutoController]
class NewsController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;

    /**
     * @var NewsServiceInterface
     */
    #[Inject]
    private $newsServiceClient;

    /**
     * 导航池列表
     * @return void
     */
    public function getCategoryList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=> 'required',
                'pageSize'=> 'required',
            ],
            [
                'page.required' => '第几页不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }


        $result = $this->newsServiceClient->getCategoryList($requireData);
        if($result['data']){
            foreach ($result['data']['rows'] as $k=>$v) {
                $result['data']['rows'][$k]['pid_arr'] = $v['pid_arr']?json_decode($v['pid_arr']):[0];
            }
        }
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 分类列表
     * @return void
     */
    public function categoryList()
    {
        $requireData['website_id'] = $this->websiteId;
        $result = $this->newsServiceClient->categoryList($requireData);
        var_dump($result);
        $rep = PublicData::buildMenuTree($result['data']);
        return $result ? Result::success($rep) : Result::error($result['message']);
    }

    /**
     * 添加导航
     * @return array|void
     */
    public function addCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name'=> 'required',
                'seo_title'=> 'required',
                'seo_keywords'=> 'required',
                'seo_description'=> 'required',
            ],
            [
                'name.required' => '导航池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['pid'] = isset($requireData['pid_arr'])?end($requireData['pid_arr']):'';
        $requireData['pid_arr'] = isset($requireData['pid_arr'])?json_encode($requireData['pid_arr']):'';

        $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->addCategory($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新导航池
     * @return array
     */
    public function updateCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'name'=> 'required',
                'seo_title'=> 'required',
                'seo_keywords'=> 'required',
                'seo_description'=> 'required',
            ],
            [
                'id.required' =>'ID不能为空',
                'name.required' => '栏目池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['pid'] = isset($requireData['pid_arr'])?end($requireData['pid_arr']):'';
        $requireData['pid_arr'] = isset($requireData['pid_arr'])?json_encode($requireData['pid_arr']):'';

        $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->updateCategory($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->delCategory($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 资讯列表
     * @return void
     */
    public function getArticleList()
    {
        $requireData = $this->request->all();
        $requireData['website_id'] = $this->websiteId;
        var_dump("资讯：",$requireData);
        $result = $this->newsServiceClient->getArticleList($requireData);
        //1通过，2待审核，3待发 4,拒绝 5删除
        $statusList = [
            '1'=>'通过',
            '2'=>'待审核',
            '3'=>'待发',
            '4'=>'拒绝',
            '5'=>'删除',
        ];
        if($result['data']){
            foreach ($result['data']['rows'] as $k=>$v) {
                $result['data']['rows'][$k]['cat_arr_id'] = $v['cat_arr_id']?json_decode($v['cat_arr_id']):[0];
                $result['data']['rows'][$k]['tag'] = $v['tag']?json_decode($v['tag']):[];
                $result['data']['rows'][$k]['status_name'] = $statusList[$v['status']];
                $result['data']['rows'][$k]['level'] = (string)$v['level'];
                $result['data']['rows'][$k]['islink'] = isset($v['islink']) && $v['islink']>0?true:false;
            }
        }
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取导航池信息
     * @return void
     */
    public function getCategoryInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getCategoryInfo($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 添加分类
     * @return array|void
     */
    public function addArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title'=> 'required',
                'catid'=> 'required',
                'author'=> 'required',

            ],
            [
                'title.required' => '标题不能为空',
                'catid.required' => '分类不能为空',
                'author.required' => '作者不能为空',
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if(isset($requireData['catid']) && is_array($requireData['catid'])){
            $requireData['cat_arr_id'] = json_encode($requireData['catid']);
            $requireData['catid'] = end($requireData['catid']);
        }else{
            $id = [0];
            $requireData['cat_arr_id'] = json_encode($id);
            $requireData['catid'] = end($id);
        }
        $loginIp = $this->request->getHeader('x-forwarded-for')[0] ?? $this->request->getHeader('x-real-ip')[0] ?? $this->request->getServerParams()['remote_addr'] ?? '0.0.0.0';
        $requireData['ip'] = $loginIp;
        $requireData['website_id'] = $this->websiteId;
        $requireData['admin_user_id'] =Context::get("UserId");
        $result = $this->newsServiceClient->addArticle($requireData);

        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }


    public function updateArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'name'=> 'required',
            ],
            [
                'name.required' => '分类名称不能为空',
                'id.required' =>'ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if(isset($requireData['pid']) && is_array($requireData['pid'])){
            $requireData['pid_arr'] = json_encode($requireData['pid']);
            $requireData['pid'] = end($requireData['pid']);
        }else{
            $id = [0];
            $requireData['pid_arr'] = json_encode($id);
            $requireData['pid'] = end($id);
        }
        $requireData['website_id'] = $this->websiteId;
        $result = $this->newsServiceClient->updateArticle($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['website_id'] = $this->websiteId;
        $result = $this->newsServiceClient->delArticle($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取资讯信息
     * @return array
     */
    public function  getArticleInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result = $this->newsServiceClient->getArticleInfo($requireData);
        var_dump($result);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }


}